<TS language="bs" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Napravite novu adresu</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nova</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopirajte trenutno odabranu adresu u sistemski meduspremnik</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopirajte</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Zatvorite</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Izbrišite trenutno odabranu odresu sa liste</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>Unesite adresu ili oznaku za pretragu</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Izvezite podatke trenutne kartice u datoteku</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Izvezite</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>Iz&amp;brišite</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Izaberite adresu na koju ćete poslati novac</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Izaberite adresu na koju ćete primiti novac</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>&amp;Izaberite</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Adrese pošiljalaca</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Adrese primalaca</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Ovo su vaše Bitcoin adrese za slanje novca. Uvijek provjerite iznos i adresu primaoca prije slanja novca.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;Kopirajte adresu</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kopirajte &amp;ozanku</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Uredite</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Izvezite listu adresa</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Datoteka podataka odvojenih zarezima (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Izvoz neuspješan</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Došlo je do greške kod spašavanja liste adresa na %1. Molimo pokušajte ponovo.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Oznaka</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nema oznake)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Dijalog Lozinke</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Unesi lozinku</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nova lozinka</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Ponovi novu lozinku</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation>Prikaži lozinku</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Šifriraj novčanik</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Za otključavanje novčanika za ovu operaciju potrebna je lozinka vašeg novčanika.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Otključajte novčanik</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Ova radnja treba lozinku vašeg novčanika da dešifrira novčanik.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Dešifrirati novčanik</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Promijenite lozinku</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Potvrdite šifriranje novčanika</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation>Upozorenje: Ako šifrirate novčanik i izgubite lozinku, &lt;b&gt;IZGUBIT ĆETE SVE SVOJE BITKOINE!&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Jeste li sigurni da želite šifrirati novčanik?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Novčanik šifriran</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Unesite novu lozinku za novčanik.&lt;br/&gt;Upotrijebite lozinku od &lt;b&gt;deset ili više nasumičnih znakova&lt;/b&gt; ili &lt;b&gt;osam ili više riječi&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation>Unesite staru i novu lozinku za novčanik.</translation>
    </message>
    <message>
        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation>Imajte na umu da šifriranje vašeg novčanika ne može u potpunosti zaštititi vaše bitcoine od krađe zlonamjernim softverom koji zarazi vaš računar.</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation>Novčanik za šifriranje</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation>Novčanik će uskoro biti šifriran.</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation>Novčanik je sada šifriran.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>VAŽNO: Sve prethodne sigurnosne kopije datoteke novčanika koje ste napravili treba zamijeniti novo generiranom, šifriranom datotekom novčanika. Iz sigurnosnih razloga, prethodne sigurnosne kopije nešifrirane datoteke novčanika postat će beskorisne čim započnete koristiti novi, šifrirani novčanik.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Šifriranje novčanika nije uspjelo</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Šifriranje novčanika nije uspjelo zbog interne greške. Vaš novčanik nije šifriran.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Upisane lozinke se ne podudaraju.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Otključavanje novčanika nije uspjelo</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Lozinka unesena za dešifriranje novčanika nije ispravna.</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Dešifriranje novčanika neuspješno</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Lozinka za novčanik uspješno je promijenjena.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Upozorenje: Tipka Caps Lock je uključena!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>Banned Until</source>
        <translation>Zabranjeno Do</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Potpiši i pošalji poruku...</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Sinkronizacija s mrežom...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Pregled</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Prikaži opšti pregled novčanika</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Transakcije</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Pregledajte historiju transakcija</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Izlaz</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Zatvori aplikaciju</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;O %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>Prikaži informacije o %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Prikaži informacije o Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opcije...</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation>Izmijenite opcije konfiguracije za %1</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Šifriraj novčanik...</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>&amp;Rezervni Novčanik...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Promijeni lozinku...</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Otvori &amp;URI...</translation>
    </message>
    <message>
        <source>Create Wallet...</source>
        <translation>Kreirajte novčanik...</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation>Kreirajte novi novčanik</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>Novčanik:</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation>Mrežna aktivnost je onemogućena.</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)...</source>
        <translation>Sinkroniziranje Zaglavlja (%1%)...</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>Ponovno indeksiranje blokova na disku...</translation>
    </message>
    <message>
        <source>Proxy is &lt;b&gt;enabled&lt;/b&gt;: %1</source>
        <translation>Proxy je &lt;b&gt;omogućen&lt;/b&gt;: %1</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation>Pošaljite kovanice na Bitcoin adresu</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>Izradite sigurnosnu kopiju novčanika na drugoj lokaciji</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Promijenite lozinku koja se koristi za šifriranje novčanika</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Potvrdi poruku...</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Pošalji</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Primite</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Prikaži / Sakrij</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>Prikažite ili sakrijte glavni prozor</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>Šifrirajte privatne ključeve koji pripadaju vašem novčaniku</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation>Potpišite poruke sa svojim Bitcoin adresama da biste dokazali da ste njihov vlasnik</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation>Potvrdite poruke kako biste bili sigurni da su potpisane navedenim Bitcoin adresama</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datoteka</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Postavke</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoć</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Alatna traka kartica</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation>Zatražite uplate (generira QR kodove i bitcoin: URI-je)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation>Prikažite listu korištenih adresa i oznaka za slanje</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation>Prikažite listu korištenih adresa i oznaka za prijem</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation>&amp;Opcije komandne linije</translation>
    </message>
    <message>
        <source>Indexing blocks on disk...</source>
        <translation>Indeksiranje blokova na disku...</translation>
    </message>
    <message>
        <source>Processing blocks on disk...</source>
        <translation>Obrada blokova na disku...</translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 iza</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation>Posljednji primljeni blok generiran je prije %1.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation>Transakcije nakon ovoga još neće biti vidljive.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Greška</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Upozorenje</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informacije</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>U toku</translation>
    </message>
    <message>
        <source>&amp;Load PSBT from file...</source>
        <translation>&amp;Učitaj PSBT iz datoteke...</translation>
    </message>
    <message>
        <source>Load Partially Signed Bitcoin Transaction</source>
        <translation>Učitajte Djelomično Potpisanu Bitcoin Transakciju</translation>
    </message>
    <message>
        <source>Load PSBT from clipboard...</source>
        <translation>Učitaj PSBT iz međuspremnika...</translation>
    </message>
    <message>
        <source>Load Partially Signed Bitcoin Transaction from clipboard</source>
        <translation>Učitajte djelomično potpisanu bitcoin transakciju iz međuspremnika</translation>
    </message>
    <message>
        <source>Node window</source>
        <translation>Prozor čvora</translation>
    </message>
    <message>
        <source>Open node debugging and diagnostic console</source>
        <translation>Otvorite čvor za ispravljanje pogrešaka i dijagnostičku konzolu</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation>&amp;Slanje adresa</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation>&amp;Primanje adresa</translation>
    </message>
    <message>
        <source>Open a bitcoin: URI</source>
        <translation>Otvorite bitcoin: URI</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation>Otvorite Novčanik</translation>
    </message>
    <message>
        <source>Open a wallet</source>
        <translation>Otvorite Novčanik</translation>
    </message>
    <message>
        <source>Close Wallet...</source>
        <translation>Zatvori Novčanik...</translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation>Zatvori novčanik</translation>
    </message>
    <message>
        <source>Close All Wallets...</source>
        <translation>Zatvori sve novčanike...</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation>Zatvori sve novčanike</translation>
    </message>
    <message>
        <source>Show the %1 help message to get a list with possible Bitcoin command-line options</source>
        <translation>Pokažite %1 poruku za pomoć da biste dobili listu s mogućim opcijama Bitcoin naredbenog retka</translation>
    </message>
    <message>
        <source>&amp;Mask values</source>
        <translation>&amp;Vrijednosti maske</translation>
    </message>
    <message>
        <source>Mask the values in the Overview tab</source>
        <translation>Maskirajte vrijednosti na kartici Pregled</translation>
    </message>
    <message>
        <source>No wallets available</source>
        <translation>Nema dostupnih novčanika</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Prozor</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Minimizirajte</translation>
    </message>
    <message>
        <source>Main Window</source>
        <translation>Glavni Prozor</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation>%1 klijent</translation>
    </message>
    <message>
        <source>Click for more actions.</source>
        <extracomment>A substring of the tooltip. "More actions" are available via the context menu.</extracomment>
        <translation type="unfinished">Klikni za još radnji</translation>
    </message>
    <message>
        <source>Disable network activity</source>
        <extracomment>A context menu item.</extracomment>
        <translation type="unfinished">Onemogući rad mreže</translation>
    </message>
    <message>
        <source>Connecting to peers...</source>
        <translation>Povezivanje s vršnjacima...</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Nadoknađujem...</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Greška: %1</translation>
    </message>
    <message>
        <source>Warning: %1</source>
        <translation>Upozorenje: %1</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation>Datum: %1</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation>Iznos: %1
</translation>
    </message>
    <message>
        <source>Wallet: %1
</source>
        <translation>Novčanik: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation>Tip: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation>Oznaka: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation>Adresa: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Pošalji transakciju</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Dolazna transakcija</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;enabled&lt;/b&gt;</source>
        <translation>Stvaranje HD ključa je &lt;b&gt;omogućeno&lt;/b&gt;</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation>Stvaranje HD ključa je &lt;b&gt;onemogućeno&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Private key &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation>Privatni ključ je &lt;b&gt;onemogućen&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>Novčanik je &lt;b&gt;šifriran&lt;/b&gt; i trenutno je &lt;b&gt;unzaključan&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Novčanik je &lt;b&gt;šifriran&lt;/b&gt; i trenutno je &lt;b&gt;zaključan&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Original message:</source>
        <translation>Orginalna poruka:</translation>
    </message>
    <message>
        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
        <translation>Dogodila se fatalna greška. %1 više ne može sigurno nastaviti i prestat će raditi.</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation>Izbor Novčića</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Količina:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bajtovi:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Iznos:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Naknada:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Prašina:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Naknada nakon plaćanja:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Promjena:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation>(ne)odaberi sve</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation>Primaz kao stablo</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation>Način liste</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Iznos</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation>Primljeno sa etiketom</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation>Primljeno sa adresom</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Potvrde</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Potvrđeno</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopiraj iznos</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Kopiraj adresu</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Kopiraj naljepnicu</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;Kopiraj iznos</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID</source>
        <translation type="unfinished">&amp;Kopirajte ID transakcije</translation>
    </message>
    <message>
        <source>L&amp;ock unspent</source>
        <translation type="unfinished">&amp;Zaključaj nepotrošeno</translation>
    </message>
    <message>
        <source>&amp;Unlock unspent</source>
        <translation type="unfinished">&amp;Odključaj nepotrošeno</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopiraj količinu</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopiraj naknadu</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Kopiraj vrijednost poslije naknade</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopiraj bajte</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Kopiraj prašinu</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopiraj promjenu</translation>
    </message>
    <message>
        <source>(%1 locked)</source>
        <translation>(%1 zaključano)</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>da</translation>
    </message>
    <message>
        <source>no</source>
        <translation>ne</translation>
    </message>
    <message>
        <source>This label turns red if any recipient receives an amount smaller than the current dust threshold.</source>
        <translation>Ova naljepnica postaje crvena ako bilo koji primatelj primi količinu manju od trenutnog praga prašine.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nema oznake)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>promjena iz %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(promjeni)</translation>
    </message>
</context>
<context>
    <name>CreateWalletActivity</name>
    <message>
        <source>Create Wallet</source>
        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
        <translation>Kreirajte Novčanik</translation>
    </message>
    <message>
        <source>Creating Wallet &lt;b&gt;%1&lt;/b&gt;...</source>
        <extracomment>Descriptive text of the create wallet progress window which indicates to the user which wallet is currently being created.</extracomment>
        <translation>Kreiranje novčanika &lt;b&gt;%1&lt;/b&gt;...</translation>
    </message>
    <message>
        <source>Create wallet failed</source>
        <translation>Izrada novčanika nije uspjela</translation>
    </message>
    <message>
        <source>Create wallet warning</source>
        <translation>Stvorite upozorenje novčanika</translation>
    </message>
</context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Create Wallet</source>
        <translation>Kreirajte Novčanik</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Novčanik</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <translation>Ime Novčanika</translation>
    </message>
    <message>
        <source>Encrypt the wallet. The wallet will be encrypted with a passphrase of your choice.</source>
        <translation>Šifrirajte novčanik. Novčanik će biti šifriran lozinkom po vašem izboru.</translation>
    </message>
    <message>
        <source>Encrypt Wallet</source>
        <translation>Šifrirajte Novčanik</translation>
    </message>
    <message>
        <source>Advanced Options</source>
        <translation>Napredne Opcije</translation>
    </message>
    <message>
        <source>Disable private keys for this wallet. Wallets with private keys disabled will have no private keys and cannot have an HD seed or imported private keys. This is ideal for watch-only wallets.</source>
        <translation>Onemogućite privatne ključeve za ovaj novčanik. Novčanici s onemogućenim privatnim ključevima neće imati privatne ključeve i ne mogu imati HD sjeme ili uvezene privatne ključeve. Ovo je idealno za novčanike za gledanje.</translation>
    </message>
    <message>
        <source>Disable Private Keys</source>
        <translation>Onemogućite Privatne Ključeve</translation>
    </message>
    <message>
        <source>Make a blank wallet. Blank wallets do not initially have private keys or scripts. Private keys and addresses can be imported, or an HD seed can be set, at a later time.</source>
        <translation>Napravite prazan novčanik. Prazni novčanici u početku nemaju privatne ključeve ili skripte. Privatni ključevi i adrese mogu se kasnije uvoziti ili postaviti HD seme.</translation>
    </message>
    <message>
        <source>Make Blank Wallet</source>
        <translation>Napravi Prazan Novčanik</translation>
    </message>
    <message>
        <source>Use descriptors for scriptPubKey management</source>
        <translation>Koristite deskriptore za upravljanje scriptPubKey</translation>
    </message>
    <message>
        <source>Descriptor Wallet</source>
        <translation>Deskriptor Novčanik</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Napravi</translation>
    </message>
    <message>
        <source>Compiled without sqlite support (required for descriptor wallets)</source>
        <translation>Sastavljeno bez podrške za sqlite (potrebno za deskriptorske novčanike)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Uredi Adresu</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Oznaka</translation>
    </message>
    <message>
        <source>The label associated with this address list entry</source>
        <translation>Oznaka povezana s ovim unosom liste adresa</translation>
    </message>
    <message>
        <source>The address associated with this address list entry. This can only be modified for sending addresses.</source>
        <translation>Adresa povezana s ovim unosom liste adresa. Ovo se može izmijeniti samo za slanje adresa.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Adresa</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Nova adresa za slanje</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Uredite adresu prijema</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Uredite adresu za slanje</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Bitcoin address.</source>
        <translation>Unesena adresa "%1" nije važeća Bitcoin adresa.</translation>
    </message>
    <message>
        <source>Address "%1" already exists as a receiving address with label "%2" and so cannot be added as a sending address.</source>
        <translation>Adresa "%1" već postoji kao adresa primatelja s oznakom "%2" i zato se ne može dodati kao adresa za slanje.</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book with label "%2".</source>
        <translation>Unesena adresa "%1" već je u adresaru sa oznakom "%2".</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Nije moguće otključati novčanik.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Nova generacija ključeva nije uspjela.</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>A new data directory will be created.</source>
        <translation>Stvorit će se novi direktorij podataka.</translation>
    </message>
    <message>
        <source>name</source>
        <translation>ime</translation>
    </message>
    <message>
        <source>Directory already exists. Add %1 if you intend to create a new directory here.</source>
        <translation>Direktorij već postoji. Dodajte %1 ako ovdje namjeravate stvoriti novi direktorij.</translation>
    </message>
    <message>
        <source>Path already exists, and is not a directory.</source>
        <translation>Put već postoji i nije direktorij.</translation>
    </message>
    <message>
        <source>Cannot create data directory here.</source>
        <translation>Ovdje nije moguće stvoriti direktorij podataka.</translation>
    </message>
</context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>verzija</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>O %1</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>Opcije komandne linije</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>Dobrodošli</translation>
    </message>
    <message>
        <source>Welcome to %1.</source>
        <translation>Dobrodošli u %1.</translation>
    </message>
    <message>
        <source>As this is the first time the program is launched, you can choose where %1 will store its data.</source>
        <translation>Zato što je ovo prvi put da se program pokreće, možete odabrati gdje će %1 čuvati svoje podatke.</translation>
    </message>
    <message>
        <source>When you click OK, %1 will begin to download and process the full %4 block chain (%2GB) starting with the earliest transactions in %3 when %4 initially launched.</source>
        <translation>Kada kliknete OK, %1 će početi preuzimati i obrađivati ​​puni lanac blokova %4 (%2GB), počevši od najranijih transakcija u %3 kada je %4 isprva pokrenut.</translation>
    </message>
    <message>
        <source>Reverting this setting requires re-downloading the entire blockchain. It is faster to download the full chain first and prune it later. Disables some advanced features.</source>
        <translation>Vraćanje ove postavke zahtijeva ponovno preuzimanje cijelog lanca blokova. Brže je prvo preuzeti čitav lanac i kasnije ga obrezati. Onemogućava neke napredne funkcije.</translation>
    </message>
    <message>
        <source>If you have chosen to limit block chain storage (pruning), the historical data must still be downloaded and processed, but will be deleted afterward to keep your disk usage low.</source>
        <translation>Ako ste odlučili ograničiti skladištenje lanca blokova (obrezivanje), povijesni podaci i dalje se moraju preuzeti i obraditi, ali će se nakon toga izbrisati kako bi se smanjila upotreba diska.</translation>
    </message>
    <message>
        <source>Use the default data directory</source>
        <translation>Koristite zadani direktorij podataka</translation>
    </message>
    <message>
        <source>Use a custom data directory:</source>
        <translation>Koristite prilagođeni direktorij podataka:</translation>
    </message>
    <message>
        <source>At least %1 GB of data will be stored in this directory, and it will grow over time.</source>
        <translation>Najmanje %1 GB podataka bit će pohranjeno u ovom direktoriju i vremenom će rasti.</translation>
    </message>
    <message>
        <source>Approximately %1 GB of data will be stored in this directory.</source>
        <translation>Otprilike %1 GB podataka bit će pohranjeno u ovom direktoriju.</translation>
    </message>
    <message>
        <source>%1 will download and store a copy of the Bitcoin block chain.</source>
        <translation>%1 će preuzeti i pohraniti kopiju lanca Bitcoin blokova.</translation>
    </message>
    <message>
        <source>The wallet will also be stored in this directory.</source>
        <translation>Novčanik će također biti pohranjen u ovom imeniku.</translation>
    </message>
    <message>
        <source>Error: Specified data directory "%1" cannot be created.</source>
        <translation>Greška: Navedeni direktorij podataka "%1" ne može se kreirati.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Greška</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation>Obrazac</translation>
    </message>
    <message>
        <source>Recent transactions may not yet be visible, and therefore your wallet's balance might be incorrect. This information will be correct once your wallet has finished synchronizing with the bitcoin network, as detailed below.</source>
        <translation>Nedavne transakcije možda još nisu vidljive, pa stoga stanje na vašem novčaniku može biti pogrešno. Ove će informacije biti točne nakon što se novčanik završi sa sinhronizacijom s bitcoin mrežom, kao što je detaljno opisano u nastavku.</translation>
    </message>
    <message>
        <source>Attempting to spend bitcoins that are affected by not-yet-displayed transactions will not be accepted by the network.</source>
        <translation>Pokušaj trošenja bitcoina na koje utječu još uvijek ne prikazane transakcije mreža neće prihvatiti.</translation>
    </message>
    <message>
        <source>Number of blocks left</source>
        <translation>Broj preostalih blokova</translation>
    </message>
    <message>
        <source>Unknown...</source>
        <translation>Nepoznato...</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Vrijeme zadnjeg bloka</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Napredak</translation>
    </message>
    <message>
        <source>Progress increase per hour</source>
        <translation>Povećanje napretka po satu</translation>
    </message>
    <message>
        <source>calculating...</source>
        <translation>računanje...</translation>
    </message>
    <message>
        <source>Estimated time left until synced</source>
        <translation>Procijenjeno vrijeme do sinhronizacije</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Sakrij</translation>
    </message>
    <message>
        <source>%1 is currently syncing.  It will download headers and blocks from peers and validate them until reaching the tip of the block chain.</source>
        <translation>%1 se trenutno sinhronizira. Preuzet će zaglavlja i blokove sa vršnjaka i provjeriti ih dok ne dođu do vrha lanca blokova.</translation>
    </message>
    <message>
        <source>Unknown. Syncing Headers (%1, %2%)...</source>
        <translation>Nepoznato. Sinhronizacija Zaglavlja (%1, %2%)...</translation>
    </message>
</context>
<context>
    <name>NetWatchLogModel</name>
    <message>
        <source>Address</source>
        <comment>NetWatch: Address header</comment>
        <translation>Adresa</translation>
    </message>
</context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Open bitcoin URI</source>
        <translation>Otvorite bitcoin URI</translation>
    </message>
    </context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>default wallet</source>
        <translation>zadani novčanik</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
        <translation>Otvorite Novčanik</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opcije</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Glavni</translation>
    </message>
    <message>
        <source>Automatically start %1 after logging in to the system.</source>
        <translation>Automatski pokreni %1 nakon prijave u sistem.</translation>
    </message>
    <message>
        <source>&amp;Start %1 on system login</source>
        <translation>&amp;Pokrenite %1 na sistemskoj prijavi</translation>
    </message>
    <message>
        <source>Size of &amp;database cache</source>
        <translation>Veličina predmemorije &amp;database</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
        <translation>IP adresa proxyja (npr. IPv4: 127.0.0.1 / IPv6: ::1)</translation>
    </message>
    <message>
        <source>Shows if the supplied default SOCKS5 proxy is used to reach peers via this network type.</source>
        <translation>Pokazuje da li se isporučeni zadani SOCKS5 proxy koristi za dosezanje vršnjaka putem ovog tipa mreže.</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Exit in the menu.</source>
        <translation>Smanjite, umjesto da izađete iz aplikacije kada je prozor zatvoren. Kada je ova opcija omogućena, aplikacija će se zatvoriti tek nakon odabira Izlaz u izborniku.</translation>
    </message>
    <message>
        <source>Third party URLs (e.g. a block explorer) that appear in the transactions tab as context menu items. %s in the URL is replaced by transaction hash. Multiple URLs are separated by vertical bar |.</source>
        <translation>URL-ovi trećih strana (npr. Istraživač blokova) koji se na kartici transakcija pojavljuju kao stavke kontekstnog izbornika.%s u URL-u se zamjenjuje hešom transakcije. Više URL-ova odvojeno je okomitom trakom |.</translation>
    </message>
    <message>
        <source>Open the %1 configuration file from the working directory.</source>
        <translation>Otvorite datoteku konfiguracije %1 iz radnog direktorija.</translation>
    </message>
    <message>
        <source>Open Configuration File</source>
        <translation>Otvorite Konfiguracijsku Datoteku</translation>
    </message>
    <message>
        <source>Reset all client options to default.</source>
        <translation>Vratite sve opcije klijenta na zadane.</translation>
    </message>
    <message>
        <source>&amp;Reset Options</source>
        <translation>&amp;Resetiraj opcije</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Mreža</translation>
    </message>
    <message>
        <source>Disables some advanced features but all blocks will still be fully validated. Reverting this setting requires re-downloading the entire blockchain. Actual disk usage may be somewhat higher.</source>
        <translation>Onemogućuje neke napredne stavke ali svi blokovi će i dalje biti u potpunosti validni(provjereni). Opoziv ove postavke zahtijeva ponovno skidanje čitavog blockchaina. Stvarna iskorištenost diska može da bude nešto veća.</translation>
    </message>
    <message>
        <source>Reverting this setting requires re-downloading the entire blockchain.</source>
        <translation>Vraćanje ove postavke zahtijeva ponovno preuzimanje cijelog lanca blokova.</translation>
    </message>
    <message>
        <source>(0 = auto, &lt;0 = leave that many cores free)</source>
        <translation>(0 = automatski, &lt;0 = ostavi toliko jezgara slobodnim)</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation type="unfinished">&amp;Novčanik</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation>Stručnjak</translation>
    </message>
    <message>
        <source>If you disable the spending of unconfirmed change, the change from a transaction cannot be used until that transaction has at least one confirmation. This also affects how your balance is computed.</source>
        <translation>Ako onemogućite trošenje nepotvrđene promjene, promjena iz transakcije neće se moći koristiti dok ta transakcija nema barem jednu potvrdu. Ovo također utječe na način izračunavanja vašeg stanja.</translation>
    </message>
    <message>
        <source>Automatically open the Bitcoin client port on the router. This only works when your router supports UPnP and it is enabled.</source>
        <translation>Automatski otvorite port Bitcoin klijenta na usmjerivaču. Ovo radi samo kada vaš usmjerivač podržava UPnP i ako je omogućen.</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Map port koristi &amp;UPnP</translation>
    </message>
    <message>
        <source>Accept connections from outside.</source>
        <translation>Prihvatite veze izvana.</translation>
    </message>
    <message>
        <source>Connect to the Bitcoin network through a SOCKS5 proxy.</source>
        <translation>Povežite se s Bitcoin mrežom putem SOCKS5 proxyja.</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Port proxyja (npr. 9050)</translation>
    </message>
    <message>
        <source>Used for reaching peers via:</source>
        <translation>Koristi se za dosezanje vršnjaka putem:</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Prozor</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Prikažite samo ikonu ladice nakon umanjivanja prozora.</translation>
    </message>
    <message>
        <source>The user interface language can be set here. This setting will take effect after restarting %1.</source>
        <translation>Ovdje se može podesiti jezik korisničkog interfejsa. Ova postavka će stupiti na snagu nakon ponovnog pokretanja %1.</translation>
    </message>
    <message>
        <source>Bitcoin Core</source>
        <translation>Bitcoin Jezrga</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Greška</translation>
    </message>
    <message>
        <source>The configuration file could not be opened.</source>
        <translation>Konfiguracijski falj nije bilo moguce otvoriti.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Obrazac</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Bitcoin network after a connection is established, but this process has not completed yet.</source>
        <translation>Moguće je da su prikazane informacije zastarjele.Vaš novčanik se automatski sinhronizira sa Bitcoin mrežom nakon što je konekcija uspostavljena, ali proces nije još uvijek dovršen.</translation>
    </message>
    <message>
        <source>Recent transactions</source>
        <translation>Nedavne transakcije</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Close</source>
        <translation type="unfinished">Zatvorite</translation>
    </message>
    </context>
<context>
    <name>PairingPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Iznos</translation>
    </message>
    <message>
        <source>Error: Specified data directory "%1" does not exist.</source>
        <translation>Greška: Navedeni direktorij podataka "%1" ne postoji.</translation>
    </message>
    <message>
        <source>Error: Cannot parse configuration file: %1.</source>
        <translation>Greška: Nije moguće parsirati konfiguracijsku datoteku: %1.</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Greška: %1</translation>
    </message>
    <message>
        <source>%1 didn't yet exit safely...</source>
        <translation>%1 još nije sigurno izašlo...</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>nepoznato</translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation type="unfinished">&amp;Informacije</translation>
    </message>
    <message>
        <source>Network</source>
        <translation type="unfinished">Mreža</translation>
    </message>
    <message>
        <source>Wallet: </source>
        <translation type="unfinished">Novčanik: </translation>
    </message>
    <message>
        <source>Node window</source>
        <translation>Prozor čvora</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Vrijeme zadnjeg bloka</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer</extracomment>
        <translation type="unfinished">&amp;Kopiraj adresu</translation>
    </message>
    <message>
        <source>Network activity disabled</source>
        <translation type="unfinished">Mrežna aktivnost je onemogućena</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished">Nepoznato</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation type="unfinished">&amp;Iznos:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;Oznaka:</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Kopiraj adresu</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Kopiraj naljepnicu</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;Kopiraj iznos</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Nije moguće otključati novčanik.</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address:</source>
        <translation type="unfinished">Adresa:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Iznos:</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation type="unfinished">Oznaka:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>Novčanik:</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation type="unfinished">&amp;Kopirajte adresu</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Oznaka</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nema oznake)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Količina:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bajtovi:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Iznos:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Naknada:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Naknada nakon plaćanja:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Promjena:</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation type="unfinished">Izaberite...</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Sakrij</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Prašina:</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation type="unfinished">&amp;Pošalji</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopiraj količinu</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopiraj iznos</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopiraj naknadu</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Kopiraj vrijednost poslije naknade</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopiraj bajte</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Kopiraj prašinu</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopiraj promjenu</translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished">Pošalji</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nema oznake)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation type="unfinished">&amp;Iznos:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;Oznaka:</translation>
    </message>
    </context>
<context>
    <name>ShutdownWindow</name>
    <message>
        <source>%1 is shutting down...</source>
        <translation>%1 se gasi...</translation>
    </message>
    <message>
        <source>Do not shut down the computer until this window disappears.</source>
        <translation>Ne isključujte računar dok ovaj prozor ne nestane.</translation>
    </message>
</context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Potvrdi poruku</translation>
    </message>
    <message>
        <source>Verify &amp;Message</source>
        <translation type="unfinished">&amp;Potvrdi poruku</translation>
    </message>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>nepoznato</translation>
    </message>
    <message>
        <source>Transaction</source>
        <translation>transakciju</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Iznos</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Oznaka</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nema oznake)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>All</source>
        <translation>Sve</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Danas</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Ovaj mjesec</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Prošli mjesec</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Ove godine</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Kopiraj adresu</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Kopiraj naljepnicu</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;Kopiraj iznos</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID</source>
        <translation type="unfinished">&amp;Kopirajte ID transakcije</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Datoteka podataka odvojenih zarezima (*.csv)</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Potvrđeno</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Oznaka</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Izvoz neuspješan</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    <message>
        <source>Unit to show amounts in. Click to select another unit.</source>
        <translation>Jedinica u kojoj se prikazuju iznosi. Kliknite za odabir druge jedinice.</translation>
    </message>
</context>
<context>
    <name>WalletController</name>
    <message>
        <source>Close wallet</source>
        <translation>Zatvori novčanik</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation>Zatvori sve novčanike</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation>Kreirajte novi novčanik</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Greška</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>default wallet</source>
        <translation>zadani novčanik</translation>
    </message>
</context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Izvezite</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Izvezite podatke trenutne kartice u datoteku</translation>
    </message>
    <message>
        <source>Backup Wallet</source>
        <translation type="unfinished">Rezervni Novčanik</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Unable to start HTTP server. See debug log for details.</source>
        <translation>Nije moguće pokrenuti HTTP server. Pogledajte dnevnik otklanjanja grešaka za detalje.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Greška</translation>
    </message>
    <message>
        <source>SQLiteDatabase: Failed to execute statement to verify database: %s</source>
        <translation>SQLiteDatabase: Izvršenje naredbe za provjeru baze podataka nije uspjelo: %s</translation>
    </message>
    <message>
        <source>SQLiteDatabase: Failed to prepare statement to verify database: %s</source>
        <translation>SQLiteDatabase: Nije uspjela priprema naredbe za provjeru baze podataka: %s</translation>
    </message>
    <message>
        <source>SQLiteDatabase: Failed to read database verification error: %s</source>
        <translation>SQLiteDatabase: Neuspjelo čitanje greške verifikacije baze podataka: %s</translation>
    </message>
    <message>
        <source>SQLiteDatabase: Unexpected application id. Expected %u, got %u</source>
        <translation>SQLiteDatabase: Neočekivani ID aplikacije. Ocekivao %u, dobio %u</translation>
    </message>
    <message>
        <source>Specified blocks directory "%s" does not exist.</source>
        <translation>Navedeni direktorij blokova "%s" ne postoji.</translation>
    </message>
    <message>
        <source>The specified R/W config file %s does not exist
</source>
        <translation>Navedena R/W konfiguracijska datoteka %s ne postoji
</translation>
    </message>
    <message>
        <source>Unable to open %s for writing</source>
        <translation type="unfinished">Nije moguće otvoriti %s za pisanje</translation>
    </message>
    <message>
        <source>Unknown address type '%s'</source>
        <translation>Nepoznata vrsta adrese '%s'</translation>
    </message>
    <message>
        <source>Unknown change type '%s'</source>
        <translation>Nepoznata vrsta promjene '%s'</translation>
    </message>
    <message>
        <source>Upgrading txindex database</source>
        <translation>Nadogradnja txindex baze podataka</translation>
    </message>
    <message>
        <source>Replaying blocks...</source>
        <translation type="unfinished">Reprodukcija blokova...</translation>
    </message>
    <message>
        <source>The source code is available from %s.</source>
        <translation>Izvorni kod je dostupan od %s.</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer. %s is probably already running.</source>
        <translation>Nije moguće povezati se na %s na ovom računaru. %s vjerovatno već radi.</translation>
    </message>
    <message>
        <source>Unable to generate keys</source>
        <translation type="unfinished">Nije moguće generirati ključeve</translation>
    </message>
    <message>
        <source>Unsupported logging category %s=%s.</source>
        <translation>Nepodržana kategorija logivanja %s=%s.</translation>
    </message>
    <message>
        <source>Upgrading UTXO database</source>
        <translation>Nadogradnja UTXO baze podataka</translation>
    </message>
    <message>
        <source>User Agent comment (%s) contains unsafe characters.</source>
        <translation>Komentar korisničkog agenta (%s) sadrži nesigurne znakove.</translation>
    </message>
    <message>
        <source>Verifying blocks...</source>
        <translation type="unfinished">Provjera blokova...</translation>
    </message>
    <message>
        <source>Wallet needed to be rewritten: restart %s to complete</source>
        <translation>Novčanik je trebao biti prepisan: ponovo pokrenite %s da biste završili</translation>
    </message>
    <message>
        <source>Section [%s] is not recognized.</source>
        <translation>Odjeljak [%s] nije prepoznat.</translation>
    </message>
    <message>
        <source>Signing transaction failed</source>
        <translation>Potpisivanje transakcije nije uspjelo</translation>
    </message>
    <message>
        <source>Specified -walletdir "%s" does not exist</source>
        <translation>Navedeni -walletdir "%s" ne postoji</translation>
    </message>
    <message>
        <source>Specified -walletdir "%s" is a relative path</source>
        <translation>Navedeni -walletdir "%s" je relativna putanja</translation>
    </message>
    <message>
        <source>Specified -walletdir "%s" is not a directory</source>
        <translation>Navedeni -walletdir "%s" nije direktorij</translation>
    </message>
    <message>
        <source>The specified config file %s does not exist
</source>
        <translation type="unfinished">Navedena konfiguracijska datoteka %s ne postoji
</translation>
    </message>
    <message>
        <source>The transaction amount is too small to pay the fee</source>
        <translation>Iznos transakcije je premali za plaćanje naknade</translation>
    </message>
    <message>
        <source>This is experimental software.</source>
        <translation>Ovo je eksperimentalni softver.</translation>
    </message>
    <message>
        <source>Transaction amount too small</source>
        <translation>Iznos transakcije je premali</translation>
    </message>
    <message>
        <source>Transaction too large</source>
        <translation>Transakcija je prevelika</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer (bind returned error %s)</source>
        <translation>Nije moguće povezati se na %s na ovom računaru (povezivanje je vratilo grešku %s)</translation>
    </message>
    <message>
        <source>Unable to create the PID file '%s': %s</source>
        <translation>Nije moguće kreirati PID fajl '%s': %s</translation>
    </message>
    <message>
        <source>Unable to generate initial keys</source>
        <translation>Nije moguće generirati početne ključeve</translation>
    </message>
    <message>
        <source>Unknown -blockfilterindex value %s.</source>
        <translation>Nepoznata vrijednost -blockfilterindex %s.</translation>
    </message>
    <message>
        <source>Verifying wallet(s)...</source>
        <translation type="unfinished">Provjera novčanika...</translation>
    </message>
    <message>
        <source>Starting network threads...</source>
        <translation type="unfinished">Pokretanje mrežnih niti...</translation>
    </message>
    <message>
        <source>The wallet will avoid paying less than the minimum relay fee.</source>
        <translation>Novčanik će izbjeći plaćanje manje od minimalne relejne naknade.</translation>
    </message>
    <message>
        <source>This is the minimum transaction fee you pay on every transaction.</source>
        <translation>Ovo je minimalna naknada za transakciju koju plaćate za svaku transakciju.</translation>
    </message>
    <message>
        <source>This is the transaction fee you will pay if you send a transaction.</source>
        <translation>Ovo je naknada za transakciju koju ćete platiti ako pošaljete transakciju.</translation>
    </message>
    <message>
        <source>Transaction amounts must not be negative</source>
        <translation>Iznosi transakcija ne smiju biti negativni</translation>
    </message>
    <message>
        <source>Transaction has too long of a mempool chain</source>
        <translation>Transakcija ima predugačak mempool lanac </translation>
    </message>
    <message>
        <source>Transaction must have at least one recipient</source>
        <translation>Transakcija mora imati najmanje jednog primaoca</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>Nepoznata mreža navedena u -onlynet: '%s'</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation type="unfinished">Ponovno skeniranje...</translation>
    </message>
    </context>
</TS>
